# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from fsai_grpc_api.protos import image_api_pb2 as fsai__grpc__api_dot_protos_dot_image__api__pb2


class ImageApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.FindOrCreateImage = channel.unary_unary(
                '/ImageApi/FindOrCreateImage',
                request_serializer=fsai__grpc__api_dot_protos_dot_image__api__pb2.FindOrCreateImageRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_image__api__pb2.FindOrCreateImageResponse.FromString,
                )
        self.GetImageById = channel.unary_unary(
                '/ImageApi/GetImageById',
                request_serializer=fsai__grpc__api_dot_protos_dot_image__api__pb2.GetImageByIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_image__api__pb2.GetImageByIdResponse.FromString,
                )
        self.GetImageDataById = channel.unary_stream(
                '/ImageApi/GetImageDataById',
                request_serializer=fsai__grpc__api_dot_protos_dot_image__api__pb2.GetImageDataByIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_image__api__pb2.GetImageDataByIdResponse.FromString,
                )


class ImageApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def FindOrCreateImage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetImageById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetImageDataById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ImageApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'FindOrCreateImage': grpc.unary_unary_rpc_method_handler(
                    servicer.FindOrCreateImage,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_image__api__pb2.FindOrCreateImageRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_image__api__pb2.FindOrCreateImageResponse.SerializeToString,
            ),
            'GetImageById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetImageById,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_image__api__pb2.GetImageByIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_image__api__pb2.GetImageByIdResponse.SerializeToString,
            ),
            'GetImageDataById': grpc.unary_stream_rpc_method_handler(
                    servicer.GetImageDataById,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_image__api__pb2.GetImageDataByIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_image__api__pb2.GetImageDataByIdResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ImageApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ImageApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def FindOrCreateImage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ImageApi/FindOrCreateImage',
            fsai__grpc__api_dot_protos_dot_image__api__pb2.FindOrCreateImageRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_image__api__pb2.FindOrCreateImageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetImageById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ImageApi/GetImageById',
            fsai__grpc__api_dot_protos_dot_image__api__pb2.GetImageByIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_image__api__pb2.GetImageByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetImageDataById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/ImageApi/GetImageDataById',
            fsai__grpc__api_dot_protos_dot_image__api__pb2.GetImageDataByIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_image__api__pb2.GetImageDataByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from fsai_grpc_api.protos import metric_api_pb2 as fsai__grpc__api_dot_protos_dot_metric__api__pb2


class MetricApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.FindMissionDetectionCounts = channel.unary_unary(
                '/MetricApi/FindMissionDetectionCounts',
                request_serializer=fsai__grpc__api_dot_protos_dot_metric__api__pb2.FindMissionDetectionsCountRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_metric__api__pb2.FindMissionDetectionsCountResponse.FromString,
                )
        self.FindMissionDetectionCountsByState = channel.unary_unary(
                '/MetricApi/FindMissionDetectionCountsByState',
                request_serializer=fsai__grpc__api_dot_protos_dot_metric__api__pb2.FindMissionDetectionCountsByStateRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_metric__api__pb2.FindMissionDetectionCountsByStateResponse.FromString,
                )
        self.GetTotalImagesByMissionId = channel.unary_unary(
                '/MetricApi/GetTotalImagesByMissionId',
                request_serializer=fsai__grpc__api_dot_protos_dot_metric__api__pb2.GetTotalImagesByMissionIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_metric__api__pb2.GetTotalImagesByMissionIdResponse.FromString,
                )


class MetricApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def FindMissionDetectionCounts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FindMissionDetectionCountsByState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTotalImagesByMissionId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MetricApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'FindMissionDetectionCounts': grpc.unary_unary_rpc_method_handler(
                    servicer.FindMissionDetectionCounts,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_metric__api__pb2.FindMissionDetectionsCountRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_metric__api__pb2.FindMissionDetectionsCountResponse.SerializeToString,
            ),
            'FindMissionDetectionCountsByState': grpc.unary_unary_rpc_method_handler(
                    servicer.FindMissionDetectionCountsByState,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_metric__api__pb2.FindMissionDetectionCountsByStateRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_metric__api__pb2.FindMissionDetectionCountsByStateResponse.SerializeToString,
            ),
            'GetTotalImagesByMissionId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTotalImagesByMissionId,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_metric__api__pb2.GetTotalImagesByMissionIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_metric__api__pb2.GetTotalImagesByMissionIdResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'MetricApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class MetricApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def FindMissionDetectionCounts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/MetricApi/FindMissionDetectionCounts',
            fsai__grpc__api_dot_protos_dot_metric__api__pb2.FindMissionDetectionsCountRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_metric__api__pb2.FindMissionDetectionsCountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FindMissionDetectionCountsByState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/MetricApi/FindMissionDetectionCountsByState',
            fsai__grpc__api_dot_protos_dot_metric__api__pb2.FindMissionDetectionCountsByStateRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_metric__api__pb2.FindMissionDetectionCountsByStateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTotalImagesByMissionId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/MetricApi/GetTotalImagesByMissionId',
            fsai__grpc__api_dot_protos_dot_metric__api__pb2.GetTotalImagesByMissionIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_metric__api__pb2.GetTotalImagesByMissionIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/area_of_interest_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='fsai_grpc_api/protos/area_of_interest_api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/fsai_grpc_api/protos/area_of_interest_api.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a fsai_grpc_api/protos/utils.proto\"\xa9\x01\n\x0e\x41reaOfInterest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x12\n\nmission_id\x18\x02 \x01(\x05\x12\x17\n\x0fgeo_polygon_wkt\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"N\n!FindOrCreateAreaOfInterestRequest\x12)\n\x10\x61rea_of_interest\x18\x01 \x01(\x0b\x32\x0f.AreaOfInterest\"q\n\"FindOrCreateAreaOfInterestResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12)\n\x10\x61rea_of_interest\x18\x02 \x01(\x0b\x32\x0f.AreaOfInterest\"J\n\x1d\x46indAreaOfInterestByIdRequest\x12)\n\x10\x61rea_of_interest\x18\x01 \x01(\x0b\x32\x0f.AreaOfInterest\"m\n\x1e\x46indAreaOfInterestByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12)\n\x10\x61rea_of_interest\x18\x02 \x01(\x0b\x32\x0f.AreaOfInterest\"G\n\x1aListAreaOfInterestsRequest\x12)\n\x10\x61rea_of_interest\x18\x01 \x01(\x0b\x32\x0f.AreaOfInterest\"k\n\x1bListAreaOfInterestsResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12*\n\x11\x61rea_of_interests\x18\x02 \x03(\x0b\x32\x0f.AreaOfInterest\"L\n\x1fUpdateAreaOfInterestByIdRequest\x12)\n\x10\x61rea_of_interest\x18\x01 \x01(\x0b\x32\x0f.AreaOfInterest\"o\n UpdateAreaOfInterestByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12)\n\x10\x61rea_of_interest\x18\x02 \x01(\x0b\x32\x0f.AreaOfInterest\"L\n\x1f\x44\x65leteAreaOfInterestByIdRequest\x12)\n\x10\x61rea_of_interest\x18\x01 \x01(\x0b\x32\x0f.AreaOfInterest\"o\n DeleteAreaOfInterestByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12)\n\x10\x61rea_of_interest\x18\x02 \x01(\x0b\x32\x0f.AreaOfInterest\"u\n&GetAreaOfInterestOverlapPercentRequest\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12)\n\x10\x61rea_of_interest\x18\x02 \x01(\x0b\x32\x0f.AreaOfInterest\"\x92\x01\n\'GetAreaOfInterestOverlapPercentResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12)\n\x10\x61rea_of_interest\x18\x02 \x01(\x0b\x32\x0f.AreaOfInterest\x12\x1a\n\x12overlap_percentage\x18\x03 \x01(\x02\x32\xdf\x04\n\x11\x41reaOfInterestApi\x12\x65\n\x1a\x46indOrCreateAreaOfInterest\x12\".FindOrCreateAreaOfInterestRequest\x1a#.FindOrCreateAreaOfInterestResponse\x12Y\n\x16\x46indAreaOfInterestById\x12\x1e.FindAreaOfInterestByIdRequest\x1a\x1f.FindAreaOfInterestByIdResponse\x12P\n\x13ListAreaOfInterests\x12\x1b.ListAreaOfInterestsRequest\x1a\x1c.ListAreaOfInterestsResponse\x12_\n\x18UpdateAreaOfInterestById\x12 .UpdateAreaOfInterestByIdRequest\x1a!.UpdateAreaOfInterestByIdResponse\x12_\n\x18\x44\x65leteAreaOfInterestById\x12 .DeleteAreaOfInterestByIdRequest\x1a!.DeleteAreaOfInterestByIdResponse\x12t\n\x1fGetAreaOfInterestOverlapPercent\x12\'.GetAreaOfInterestOverlapPercentRequest\x1a(.GetAreaOfInterestOverlapPercentResponseb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,fsai__grpc__api_dot_protos_dot_utils__pb2.DESCRIPTOR,])




_AREAOFINTEREST = _descriptor.Descriptor(
  name='AreaOfInterest',
  full_name='AreaOfInterest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='AreaOfInterest.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mission_id', full_name='AreaOfInterest.mission_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geo_polygon_wkt', full_name='AreaOfInterest.geo_polygon_wkt', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='AreaOfInterest.created_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='AreaOfInterest.updated_at', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=119,
  serialized_end=288,
)


_FINDORCREATEAREAOFINTERESTREQUEST = _descriptor.Descriptor(
  name='FindOrCreateAreaOfInterestRequest',
  full_name='FindOrCreateAreaOfInterestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='area_of_interest', full_name='FindOrCreateAreaOfInterestRequest.area_of_interest', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=290,
  serialized_end=368,
)


_FINDORCREATEAREAOFINTERESTRESPONSE = _descriptor.Descriptor(
  name='FindOrCreateAreaOfInterestResponse',
  full_name='FindOrCreateAreaOfInterestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='FindOrCreateAreaOfInterestResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='area_of_interest', full_name='FindOrCreateAreaOfInterestResponse.area_of_interest', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=370,
  serialized_end=483,
)


_FINDAREAOFINTERESTBYIDREQUEST = _descriptor.Descriptor(
  name='FindAreaOfInterestByIdRequest',
  full_name='FindAreaOfInterestByIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='area_of_interest', full_name='FindAreaOfInterestByIdRequest.area_of_interest', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=485,
  serialized_end=559,
)


_FINDAREAOFINTERESTBYIDRESPONSE = _descriptor.Descriptor(
  name='FindAreaOfInterestByIdResponse',
  full_name='FindAreaOfInterestByIdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='FindAreaOfInterestByIdResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='area_of_interest', full_name='FindAreaOfInterestByIdResponse.area_of_interest', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=561,
  serialized_end=670,
)


_LISTAREAOFINTERESTSREQUEST = _descriptor.Descriptor(
  name='ListAreaOfInterestsRequest',
  full_name='ListAreaOfInterestsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='area_of_interest', full_name='ListAreaOfInterestsRequest.area_of_interest', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=672,
  serialized_end=743,
)


_LISTAREAOFINTERESTSRESPONSE = _descriptor.Descriptor(
  name='ListAreaOfInterestsResponse',
  full_name='ListAreaOfInterestsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='ListAreaOfInterestsResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='area_of_interests', full_name='ListAreaOfInterestsResponse.area_of_interests', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=745,
  serialized_end=852,
)


_UPDATEAREAOFINTERESTBYIDREQUEST = _descriptor.Descriptor(
  name='UpdateAreaOfInterestByIdRequest',
  full_name='UpdateAreaOfInterestByIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='area_of_interest', full_name='UpdateAreaOfInterestByIdRequest.area_of_interest', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=854,
  serialized_end=930,
)


_UPDATEAREAOFINTERESTBYIDRESPONSE = _descriptor.Descriptor(
  name='UpdateAreaOfInterestByIdResponse',
  full_name='UpdateAreaOfInterestByIdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='UpdateAreaOfInterestByIdResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='area_of_interest', full_name='UpdateAreaOfInterestByIdResponse.area_of_interest', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=932,
  serialized_end=1043,
)


_DELETEAREAOFINTERESTBYIDREQUEST = _descriptor.Descriptor(
  name='DeleteAreaOfInterestByIdRequest',
  full_name='DeleteAreaOfInterestByIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='area_of_interest', full_name='DeleteAreaOfInterestByIdRequest.area_of_interest', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1045,
  serialized_end=1121,
)


_DELETEAREAOFINTERESTBYIDRESPONSE = _descriptor.Descriptor(
  name='DeleteAreaOfInterestByIdResponse',
  full_name='DeleteAreaOfInterestByIdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='DeleteAreaOfInterestByIdResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='area_of_interest', full_name='DeleteAreaOfInterestByIdResponse.area_of_interest', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1123,
  serialized_end=1234,
)


_GETAREAOFINTERESTOVERLAPPERCENTREQUEST = _descriptor.Descriptor(
  name='GetAreaOfInterestOverlapPercentRequest',
  full_name='GetAreaOfInterestOverlapPercentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='GetAreaOfInterestOverlapPercentRequest.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='area_of_interest', full_name='GetAreaOfInterestOverlapPercentRequest.area_of_interest', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1236,
  serialized_end=1353,
)


_GETAREAOFINTERESTOVERLAPPERCENTRESPONSE = _descriptor.Descriptor(
  name='GetAreaOfInterestOverlapPercentResponse',
  full_name='GetAreaOfInterestOverlapPercentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='GetAreaOfInterestOverlapPercentResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='area_of_interest', full_name='GetAreaOfInterestOverlapPercentResponse.area_of_interest', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overlap_percentage', full_name='GetAreaOfInterestOverlapPercentResponse.overlap_percentage', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1356,
  serialized_end=1502,
)

_AREAOFINTEREST.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_AREAOFINTEREST.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_FINDORCREATEAREAOFINTERESTREQUEST.fields_by_name['area_of_interest'].message_type = _AREAOFINTEREST
_FINDORCREATEAREAOFINTERESTRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_FINDORCREATEAREAOFINTERESTRESPONSE.fields_by_name['area_of_interest'].message_type = _AREAOFINTEREST
_FINDAREAOFINTERESTBYIDREQUEST.fields_by_name['area_of_interest'].message_type = _AREAOFINTEREST
_FINDAREAOFINTERESTBYIDRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_FINDAREAOFINTERESTBYIDRESPONSE.fields_by_name['area_of_interest'].message_type = _AREAOFINTEREST
_LISTAREAOFINTERESTSREQUEST.fields_by_name['area_of_interest'].message_type = _AREAOFINTEREST
_LISTAREAOFINTERESTSRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_LISTAREAOFINTERESTSRESPONSE.fields_by_name['area_of_interests'].message_type = _AREAOFINTEREST
_UPDATEAREAOFINTERESTBYIDREQUEST.fields_by_name['area_of_interest'].message_type = _AREAOFINTEREST
_UPDATEAREAOFINTERESTBYIDRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_UPDATEAREAOFINTERESTBYIDRESPONSE.fields_by_name['area_of_interest'].message_type = _AREAOFINTEREST
_DELETEAREAOFINTERESTBYIDREQUEST.fields_by_name['area_of_interest'].message_type = _AREAOFINTEREST
_DELETEAREAOFINTERESTBYIDRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_DELETEAREAOFINTERESTBYIDRESPONSE.fields_by_name['area_of_interest'].message_type = _AREAOFINTEREST
_GETAREAOFINTERESTOVERLAPPERCENTREQUEST.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_GETAREAOFINTERESTOVERLAPPERCENTREQUEST.fields_by_name['area_of_interest'].message_type = _AREAOFINTEREST
_GETAREAOFINTERESTOVERLAPPERCENTRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_GETAREAOFINTERESTOVERLAPPERCENTRESPONSE.fields_by_name['area_of_interest'].message_type = _AREAOFINTEREST
DESCRIPTOR.message_types_by_name['AreaOfInterest'] = _AREAOFINTEREST
DESCRIPTOR.message_types_by_name['FindOrCreateAreaOfInterestRequest'] = _FINDORCREATEAREAOFINTERESTREQUEST
DESCRIPTOR.message_types_by_name['FindOrCreateAreaOfInterestResponse'] = _FINDORCREATEAREAOFINTERESTRESPONSE
DESCRIPTOR.message_types_by_name['FindAreaOfInterestByIdRequest'] = _FINDAREAOFINTERESTBYIDREQUEST
DESCRIPTOR.message_types_by_name['FindAreaOfInterestByIdResponse'] = _FINDAREAOFINTERESTBYIDRESPONSE
DESCRIPTOR.message_types_by_name['ListAreaOfInterestsRequest'] = _LISTAREAOFINTERESTSREQUEST
DESCRIPTOR.message_types_by_name['ListAreaOfInterestsResponse'] = _LISTAREAOFINTERESTSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateAreaOfInterestByIdRequest'] = _UPDATEAREAOFINTERESTBYIDREQUEST
DESCRIPTOR.message_types_by_name['UpdateAreaOfInterestByIdResponse'] = _UPDATEAREAOFINTERESTBYIDRESPONSE
DESCRIPTOR.message_types_by_name['DeleteAreaOfInterestByIdRequest'] = _DELETEAREAOFINTERESTBYIDREQUEST
DESCRIPTOR.message_types_by_name['DeleteAreaOfInterestByIdResponse'] = _DELETEAREAOFINTERESTBYIDRESPONSE
DESCRIPTOR.message_types_by_name['GetAreaOfInterestOverlapPercentRequest'] = _GETAREAOFINTERESTOVERLAPPERCENTREQUEST
DESCRIPTOR.message_types_by_name['GetAreaOfInterestOverlapPercentResponse'] = _GETAREAOFINTERESTOVERLAPPERCENTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AreaOfInterest = _reflection.GeneratedProtocolMessageType('AreaOfInterest', (_message.Message,), {
  'DESCRIPTOR' : _AREAOFINTEREST,
  '__module__' : 'fsai_grpc_api.protos.area_of_interest_api_pb2'
  # @@protoc_insertion_point(class_scope:AreaOfInterest)
  })
_sym_db.RegisterMessage(AreaOfInterest)

FindOrCreateAreaOfInterestRequest = _reflection.GeneratedProtocolMessageType('FindOrCreateAreaOfInterestRequest', (_message.Message,), {
  'DESCRIPTOR' : _FINDORCREATEAREAOFINTERESTREQUEST,
  '__module__' : 'fsai_grpc_api.protos.area_of_interest_api_pb2'
  # @@protoc_insertion_point(class_scope:FindOrCreateAreaOfInterestRequest)
  })
_sym_db.RegisterMessage(FindOrCreateAreaOfInterestRequest)

FindOrCreateAreaOfInterestResponse = _reflection.GeneratedProtocolMessageType('FindOrCreateAreaOfInterestResponse', (_message.Message,), {
  'DESCRIPTOR' : _FINDORCREATEAREAOFINTERESTRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.area_of_interest_api_pb2'
  # @@protoc_insertion_point(class_scope:FindOrCreateAreaOfInterestResponse)
  })
_sym_db.RegisterMessage(FindOrCreateAreaOfInterestResponse)

FindAreaOfInterestByIdRequest = _reflection.GeneratedProtocolMessageType('FindAreaOfInterestByIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _FINDAREAOFINTERESTBYIDREQUEST,
  '__module__' : 'fsai_grpc_api.protos.area_of_interest_api_pb2'
  # @@protoc_insertion_point(class_scope:FindAreaOfInterestByIdRequest)
  })
_sym_db.RegisterMessage(FindAreaOfInterestByIdRequest)

FindAreaOfInterestByIdResponse = _reflection.GeneratedProtocolMessageType('FindAreaOfInterestByIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _FINDAREAOFINTERESTBYIDRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.area_of_interest_api_pb2'
  # @@protoc_insertion_point(class_scope:FindAreaOfInterestByIdResponse)
  })
_sym_db.RegisterMessage(FindAreaOfInterestByIdResponse)

ListAreaOfInterestsRequest = _reflection.GeneratedProtocolMessageType('ListAreaOfInterestsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTAREAOFINTERESTSREQUEST,
  '__module__' : 'fsai_grpc_api.protos.area_of_interest_api_pb2'
  # @@protoc_insertion_point(class_scope:ListAreaOfInterestsRequest)
  })
_sym_db.RegisterMessage(ListAreaOfInterestsRequest)

ListAreaOfInterestsResponse = _reflection.GeneratedProtocolMessageType('ListAreaOfInterestsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTAREAOFINTERESTSRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.area_of_interest_api_pb2'
  # @@protoc_insertion_point(class_scope:ListAreaOfInterestsResponse)
  })
_sym_db.RegisterMessage(ListAreaOfInterestsResponse)

UpdateAreaOfInterestByIdRequest = _reflection.GeneratedProtocolMessageType('UpdateAreaOfInterestByIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEAREAOFINTERESTBYIDREQUEST,
  '__module__' : 'fsai_grpc_api.protos.area_of_interest_api_pb2'
  # @@protoc_insertion_point(class_scope:UpdateAreaOfInterestByIdRequest)
  })
_sym_db.RegisterMessage(UpdateAreaOfInterestByIdRequest)

UpdateAreaOfInterestByIdResponse = _reflection.GeneratedProtocolMessageType('UpdateAreaOfInterestByIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEAREAOFINTERESTBYIDRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.area_of_interest_api_pb2'
  # @@protoc_insertion_point(class_scope:UpdateAreaOfInterestByIdResponse)
  })
_sym_db.RegisterMessage(UpdateAreaOfInterestByIdResponse)

DeleteAreaOfInterestByIdRequest = _reflection.GeneratedProtocolMessageType('DeleteAreaOfInterestByIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEAREAOFINTERESTBYIDREQUEST,
  '__module__' : 'fsai_grpc_api.protos.area_of_interest_api_pb2'
  # @@protoc_insertion_point(class_scope:DeleteAreaOfInterestByIdRequest)
  })
_sym_db.RegisterMessage(DeleteAreaOfInterestByIdRequest)

DeleteAreaOfInterestByIdResponse = _reflection.GeneratedProtocolMessageType('DeleteAreaOfInterestByIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEAREAOFINTERESTBYIDRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.area_of_interest_api_pb2'
  # @@protoc_insertion_point(class_scope:DeleteAreaOfInterestByIdResponse)
  })
_sym_db.RegisterMessage(DeleteAreaOfInterestByIdResponse)

GetAreaOfInterestOverlapPercentRequest = _reflection.GeneratedProtocolMessageType('GetAreaOfInterestOverlapPercentRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETAREAOFINTERESTOVERLAPPERCENTREQUEST,
  '__module__' : 'fsai_grpc_api.protos.area_of_interest_api_pb2'
  # @@protoc_insertion_point(class_scope:GetAreaOfInterestOverlapPercentRequest)
  })
_sym_db.RegisterMessage(GetAreaOfInterestOverlapPercentRequest)

GetAreaOfInterestOverlapPercentResponse = _reflection.GeneratedProtocolMessageType('GetAreaOfInterestOverlapPercentResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETAREAOFINTERESTOVERLAPPERCENTRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.area_of_interest_api_pb2'
  # @@protoc_insertion_point(class_scope:GetAreaOfInterestOverlapPercentResponse)
  })
_sym_db.RegisterMessage(GetAreaOfInterestOverlapPercentResponse)



_AREAOFINTERESTAPI = _descriptor.ServiceDescriptor(
  name='AreaOfInterestApi',
  full_name='AreaOfInterestApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1505,
  serialized_end=2112,
  methods=[
  _descriptor.MethodDescriptor(
    name='FindOrCreateAreaOfInterest',
    full_name='AreaOfInterestApi.FindOrCreateAreaOfInterest',
    index=0,
    containing_service=None,
    input_type=_FINDORCREATEAREAOFINTERESTREQUEST,
    output_type=_FINDORCREATEAREAOFINTERESTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FindAreaOfInterestById',
    full_name='AreaOfInterestApi.FindAreaOfInterestById',
    index=1,
    containing_service=None,
    input_type=_FINDAREAOFINTERESTBYIDREQUEST,
    output_type=_FINDAREAOFINTERESTBYIDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListAreaOfInterests',
    full_name='AreaOfInterestApi.ListAreaOfInterests',
    index=2,
    containing_service=None,
    input_type=_LISTAREAOFINTERESTSREQUEST,
    output_type=_LISTAREAOFINTERESTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateAreaOfInterestById',
    full_name='AreaOfInterestApi.UpdateAreaOfInterestById',
    index=3,
    containing_service=None,
    input_type=_UPDATEAREAOFINTERESTBYIDREQUEST,
    output_type=_UPDATEAREAOFINTERESTBYIDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAreaOfInterestById',
    full_name='AreaOfInterestApi.DeleteAreaOfInterestById',
    index=4,
    containing_service=None,
    input_type=_DELETEAREAOFINTERESTBYIDREQUEST,
    output_type=_DELETEAREAOFINTERESTBYIDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAreaOfInterestOverlapPercent',
    full_name='AreaOfInterestApi.GetAreaOfInterestOverlapPercent',
    index=5,
    containing_service=None,
    input_type=_GETAREAOFINTERESTOVERLAPPERCENTREQUEST,
    output_type=_GETAREAOFINTERESTOVERLAPPERCENTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_AREAOFINTERESTAPI)

DESCRIPTOR.services_by_name['AreaOfInterestApi'] = _AREAOFINTERESTAPI

# @@protoc_insertion_point(module_scope)
